@@ -3,7 +3,7 @@ from django.conf import settings
 from jutil.validators import phone_filter
 
 
-def send_sms(phone: str, message: str, sender: str = '', **kw):
+def send_sms(phone: str, message: str, sender: str = "", **kw):
     """
     Sends SMS via Kajala Group SMS API. Contact info@kajala.com for access.
     :param phone: Phone number
@@ -12,20 +12,20 @@ def send_sms(phone: str, message: str, sender: str = '', **kw):
     :param kw: Variable key-value pairs to be sent to SMS API
     :return: Response from requests.post
     """
-    if not hasattr(settings, 'SMS_TOKEN'):
-        raise Exception('Invalid configuration: settings.SMS_TOKEN missing')
+    if not hasattr(settings, "SMS_TOKEN"):
+        raise Exception("Invalid configuration: settings.SMS_TOKEN missing")
     if not sender:
         sender = settings.SMS_SENDER_NAME
     if not sender:
-        raise Exception('Invalid configuration: settings.SMS_SENDER_NAME missing')
+        raise Exception("Invalid configuration: settings.SMS_SENDER_NAME missing")
     headers = {
-        'Content-Type': 'application/json',
-        'Authorization': 'Token ' + settings.SMS_TOKEN,
+        "Content-Type": "application/json",
+        "Authorization": "Token " + settings.SMS_TOKEN,
     }
     data = {
-        'dst': phone_filter(phone),
-        'msg': message,
-        'src': sender,
+        "dst": phone_filter(phone),
+        "msg": message,
+        "src": sender,
     }
     for k, v in kw.items():
         data[k] = v
